@@ -29,23 +29,26 @@ fi
 
 INSTALL="install -o root -g root"
 
-mkdir -p /etc/laptop-mode
+mkdir -p /etc/laptop-mode /etc/laptop-mode/batt-start /etc/laptop-mode/batt-stop /etc/laptop-mode/lm-ac-start /etc/laptop-mode/lm-ac-stop /etc/laptop-mode/nolm-ac-start /etc/laptop-mode/nolm-ac-stop
+
+ALREADY_EXISTED=0
 
 if [ -f /etc/laptop-mode/laptop-mode.conf ] ; then
 	echo "Not reinstalling configuration file: /etc/laptop-mode/laptop-mode.conf exists."
+	ALREADY_EXISTED=1
 elif ( ! $INSTALL -m 600 etc/laptop-mode/laptop-mode.conf /etc/laptop-mode ) ; then
 	echo "$0: Failed to install configuration file in /etc/laptop-mode/laptop-mode.conf. Installation failed."
 	exit 12
 fi
 
-if [ -f /etc/default/laptop-mode ] ; then
+if [ -f /etc/default/laptop-mode -a "$ALREADY_EXISTED" -eq 0 ] ; then
         echo "Found old configuration file in /etc/default/laptop-mode. Moving to the new location."
 	if ( ! mv /etc/default/laptop-mode /etc/laptop-mode/laptop-mode.conf ) ; then
 		echo "$0: Failed to move old configuration file to new location."
 		exit 20
 	fi
 fi
-if [ -f /etc/sysconfig/laptop-mode ] ; then
+if [ -f /etc/sysconfig/laptop-mode -a "$ALREADY_EXISTED" -eq 0 ] ; then
         echo "Found old configuration file in /etc/sysconfig/laptop-mode. Moving to the new location."
 	if ( ! mv /etc/sysconfig/laptop-mode /etc/laptop-mode/laptop-mode.conf ) ; then
 		echo "$0: Failed to move old configuration file to new location."
@@ -53,6 +56,15 @@ if [ -f /etc/sysconfig/laptop-mode ] ; then
 	fi
 fi
 
+
+if [ -f /etc/laptop-mode/lm-profiler.conf ] ; then
+	echo "Configuration file /etc/laptop-mode/lm-profiler.conf already exists."
+elif ( ! $INSTALL -m 600 etc/laptop-mode/lm-profiler.conf /etc/laptop-mode ) ; then
+	echo "$0: Failed to install configuration file in /etc/laptop-mode/lm-profiler.conf. Installation failed."
+	exit 12
+fi
+
+
 if ( ! $INSTALL -m 700 usr/sbin/laptop_mode /usr/sbin ) ; then
 	echo "$0: Failed to install /usr/sbin/laptop_mode. Installation failed."
 	exit 11
@@ -63,6 +75,11 @@ if ( ! $INSTALL -m 700 usr/sbin/lm-syslog-setup /usr/sbin ) ; then
 	exit 25
 fi
 
+if ( ! $INSTALL -m 700 usr/sbin/lm-profiler /usr/sbin ) ; then
+	echo "$0: Failed to install /usr/sbin/lm-profiler. Installation failed."
+	exit 11
+fi
+
 ACPI_DONE=0
 if [ ! -d /proc/pmu -a -d /etc/acpi ] ; then
 	mkdir -p /etc/acpi/actions
